package WebGUI::i18n::German::Asset_DataForm;
use utf8;
our $I18N = {
  10 => {
    'lastUpdated' => '1153265537',
    'message' => 'Von'
  },
  100 => {
    'lastUpdated' => '1178796061',
    'message' => 'Sind Sie sich sicher, dass Sie diesen Tab löschen wollen?'
  },
  101 => {
    'lastUpdated' => '1178796068',
    'message' => 'Label'
  },
  102 => {
    'lastUpdated' => '1178796077',
    'message' => 'Tab bearbeiten'
  },
  103 => {
    'lastUpdated' => '1178796092',
    'message' => 'Einen neuen Tab hinzufügen'
  },
  104 => {
    'lastUpdated' => '1178796099',
    'message' => 'Tab'
  },
  '104 description' => {
    'lastUpdated' => '1178796175',
    'message' => 'Falls ein Formular mehrere Tabs besitzt wird hier definiert, welcher Tab des Formulars dieses Feld darstellt. Anderenfalls werden alle Felder auf derselben Seite dargestellt.'
  },
  105 => {
    'lastUpdated' => '1178796187',
    'message' => 'Einen Tab hinzufügen'
  },
  '105 description' => {
    'lastUpdated' => '1178796210',
    'message' => 'Einen Tab zu einem Daten Formular hinzufügen'
  },
  106 => {
    'lastUpdated' => '1178796217',
    'message' => 'Tab Template'
  },
  11 => {
    'lastUpdated' => '1178796233',
    'message' => 'An'
  },
  12 => {
    'lastUpdated' => '1178796228',
    'message' => 'Cc'
  },
  13 => {
    'lastUpdated' => '1178796239',
    'message' => 'Bcc'
  },
  14 => {
    'lastUpdated' => '1178796248',
    'message' => 'Betreff'
  },
  16 => {
    'lastUpdated' => '1178796258',
    'message' => 'Bestätigung'
  },
  '16 description' => {
    'lastUpdated' => '1178796289',
    'message' => 'Diese Nachricht wird dem Benutzer nach dem Abschicken der Daten angezeigt.'
  },
  17 => {
    'lastUpdated' => '1178796298',
    'message' => 'Email gesendet'
  },
  18 => {
    'lastUpdated' => '1178796313',
    'message' => 'Gehe zurück!'
  },
  19 => {
    'lastUpdated' => '1178796332',
    'message' => 'Sind Sie sich sicher, dass Sie dieses Feld löschen wollen?'
  },
  2 => {
    'lastUpdated' => '1178796366',
    'message' => 'Hier den Betreff ihrer Email'
  },
  20 => {
    'lastUpdated' => '1178796377',
    'message' => 'Feld bearbeiten'
  },
  21 => {
    'lastUpdated' => '1178796385',
    'message' => 'Feldname'
  },
  '21 description' => {
    'lastUpdated' => '1178796437',
    'message' => 'Der Name dieses Feldes. Dieser muss eindeutig für dieses Formular sein (d.h. kein anderes Feld darf den gleiche Namen haben).'
  },
  22 => {
    'lastUpdated' => '1178796444',
    'message' => 'Status'
  },
  '22 description' => {
    'lastUpdated' => '1178796637',
    'message' => 'Versteckte Felder sind für den Benutzer nicht sichtbar, werden aber mit der Email verschickt. Angezeigte Felder können vom Benutzer gesehen aber nicht modifiziert werden. Modifizierbare Felder k&ouml;nnen vom Benutzer bearbeitet werden. Erforderliche Felder m&uuml;ssen vom Benutzer ausgef&uuml;llt werden. Wenn Sie Versteckt oder Angezeigt wählen, m&uuml;ssen Sie Standard Werte f&uuml;r diese Felder angeben.'
  },
  23 => {
    'lastUpdated' => '1178796642',
    'message' => 'Typ'
  },
  '23 description' => {
    'lastUpdated' => '1178796698',
    'message' => 'Wählen Sie den Typ des Formularelements dieses Feldes. Dies wird auch für die Validierung der Eingabe benutzt.'
  },
  24 => {
    'lastUpdated' => '1178796709',
    'message' => 'Mögliche Werte'
  },
  '24 description' => {
    'lastUpdated' => '1178796770',
    'message' => 'Dieses Feld wird für Listentypen (Checkbox Liste, Auswahlliste ...) benutzt. Geben Sie die anzugeigenden Felder ein, je ein Feld pro Zeile.'
  },
  25 => {
    'lastUpdated' => '1178796782',
    'message' => 'Standard Wert(e)'
  },
  '25 description' => {
    'lastUpdated' => '1178796851',
    'message' => 'Geben Sie den Standardwert (falls vorhanden) für dieses Feld ein. F&uuml;r Ja/Nein Felder geben Sie bitte "yes" oder "no" ein.'
  },
  27 => {
    'lastUpdated' => '1178796861',
    'message' => 'Höhe'
  },
  '27 description' => {
    'lastUpdated' => '1178796902',
    'message' => 'Setzen Sie die Höhe dieses Feldes in Pixeln. Nur genutzt für Textbereiche und HTML-Bereiche.'
  },
  28 => {
    'lastUpdated' => '1178796923',
    'message' => 'Optionale für Textbereiche und HTML Bereiche.'
  },
  29 => {
    'lastUpdated' => '1178796955',
    'message' => 'ist erforderlich'
  },
  3 => {
    'lastUpdated' => '1178796990',
    'message' => 'Danke für ihr Feedback!'
  },
  4 => {
    'lastUpdated' => '1178796997',
    'message' => 'Versteckt'
  },
  5 => {
    'lastUpdated' => '1178797004',
    'message' => 'Angezeigt'
  },
  6 => {
    'lastUpdated' => '1178797013',
    'message' => 'Modifizierbar'
  },
  7 => {
    'lastUpdated' => '1178797058',
    'message' => 'Daten Formular bearbeiten'
  },
  73 => {
    'lastUpdated' => '1178797400',
    'message' => 'Senden'
  },
  74 => {
    'lastUpdated' => '1178797410',
    'message' => 'Daten mailen?'
  },
  '74 description' => {
    'lastUpdated' => '1178797633',
    'message' => '<p>Wenn Sie hier Ja wählen, werden einige zus&auml;tzliche Felder zu diesem Formular hinzugefügt, die f&uuml;r das Emailing relevant sind. Diese Felder werden benutzt, um die eingegebenen Daten an irgendeine Person ihrer Wahl per Email zu senden.</p> <p><strong>HINWEIS:</strong> Das &quot;An&quot; Feld akzeptiert eine Standard Email Adresse, einen WebGUI Benutzernamen oder einen WebGUI Gruppennamen. Um an mehrere Personen/Gruppen eine Email zu schicken, geben Sie diese einfach durch Komma voneinder getrennt in dieses Feld ein. </p>'
  },
  744 => {
    'lastUpdated' => '1178797655',
    'message' => 'Was wollen Sie als nächstes tun?'
  },
  '744 description' => {
    'lastUpdated' => '1178797721',
    'message' => 'Nach dem Erzeugen des Daten Formulars können Sie entweder weitere Felder hinzufügen oder zur Seite zur&uuml;ckkehren, auf der das Formular angelegt wurde.'
  },
  745 => {
    'lastUpdated' => '1178798098',
    'message' => 'Gehe zurück zur Seite.'
  },
  75 => {
    'lastUpdated' => '1178798107',
    'message' => 'Erforderlich'
  },
  76 => {
    'lastUpdated' => '1178798126',
    'message' => 'Feld hinzufügen.'
  },
  '76 description' => {
    'lastUpdated' => '1178804661',
    'message' => 'Exportieren der Daten des Formulars. Tabs als Trennzeichen zwischen den einzelnen Daten.'
  },
  77 => {
    'lastUpdated' => '1178798148',
    'message' => 'Label'
  },
  '77 description' => {
    'lastUpdated' => '1178798226',
    'message' => 'Dies ist ein Text Label, um den Benutzer darüber zu informieren, was dieses Feld repräsentiert.'
  },
  79 => {
    'lastUpdated' => '1178798236',
    'message' => 'Untertext'
  },
  '79 description' => {
    'lastUpdated' => '1178798336',
    'message' => 'Erweiterung des Labels. Zusätzliche Informationen wie die Beschreibung, was im Feld stehen soll und optionale Instruktionen für dieses Feld.'
  },
  8 => {
    'lastUpdated' => '1178798346',
    'message' => 'Breite'
  },
  '8 description' => {
    'lastUpdated' => '1178798374',
    'message' => 'Setzt die Breite der meisten Felder in Pixeln.'
  },
  80 => {
    'lastUpdated' => '1178798385',
    'message' => 'Email Template'
  },
  '80 description' => {
    'lastUpdated' => '1178798541',
    'message' => 'Wähle ein Template für die Daten, die via Email verschickt werden.'
  },
  81 => {
    'lastUpdated' => '1178798560',
    'message' => 'Bestätigung Template'
  },
  '81 description' => {
    'lastUpdated' => '1178798666',
    'message' => 'Wählen Sie ein Template, das für die Anzeige der Best&auml;tigung benutzt wird.'
  },
  82 => {
    'lastUpdated' => '1178798680',
    'message' => 'Daten Formular Template'
  },
  '82 description' => {
    'lastUpdated' => '1178798704',
    'message' => 'Wählen Sie ein Template für ihr Formular.'
  },
  84 => {
    'lastUpdated' => '1178804697',
    'message' => 'Exportiere Tab getrennt.'
  },
  85 => {
    'lastUpdated' => '1178804712',
    'message' => 'Einer pro Zeile.'
  },
  86 => {
    'lastUpdated' => '1178799132',
    'message' => 'Zeige alle Einträge.'
  },
  '86 description' => {
    'lastUpdated' => '1178799160',
    'message' => 'Zeige alle Daten, die in das Daten Formular eingegeben wurden.'
  },
  87 => {
    'lastUpdated' => '1178799170',
    'message' => 'Liste Template'
  },
  '87 description' => {
    'lastUpdated' => '1178799231',
    'message' => 'Wälen Sie ein Template, das zur Anzeige der in einem Daten Formular gespeicherten Eintr&auml;ge genutzt wird.'
  },
  88 => {
    'lastUpdated' => '1178799246',
    'message' => 'Daten Formular Liste Template'
  },
  90 => {
    'lastUpdated' => '1178799289',
    'message' => 'Diesen Eintrag löschen.'
  },
  91 => {
    'lastUpdated' => '1178799307',
    'message' => 'Alle Einträge löschen.'
  },
  'Delete entry confirmation' => {
    'lastUpdated' => '1178799338',
    'message' => 'Sind Sie sich sicher, dass Sie diesen Eintrag löschen wollen?'
  },
  'Entry ID' => {
    'lastUpdated' => '1234738254',
    'message' => 'Eingabe-ID'
  },
  'Field Position' => {
    'lastUpdated' => '1178799347',
    'message' => 'Feld Position'
  },
  'Field Position description' => {
    'lastUpdated' => '1178799415',
    'message' => 'Erlaubt es ihnen die Position des Feldes direkt zu setzen. Anders als durch die Bearbeiten Icons des Feldes.'
  },
  'Submission Date' => {
    'lastUpdated' => '1234738300',
    'message' => 'Eingabe-Datum'
  },
  'Use Default Rich Editor' => {
    'lastUpdated' => '1242497997',
    'message' => 'Standard Rich Editor verwenden'
  },
  'acknowledgement var desc' => {
    'lastUpdated' => '1178799444',
    'message' => 'Die Bestätigung, die dem Benuzter nach dem Abschicken der Daten gezeigt wird.'
  },
  'acknowlegementTemplateId' => {
    'lastUpdated' => '1178799516',
    'message' => 'Die ID des Templates, das für die Bestätigung benutzt wird, die dem Benutzer nach dem Abschicken der Daten des Daten Formulars gezeigt wird.'
  },
  'add entry' => {
    'lastUpdated' => '1295596786',
    'message' => 'Eintrag hinzufügen'
  },
  'addField.label' => {
    'lastUpdated' => '1178799545',
    'message' => 'Das Standard Label für die addField.url Variable.'
  },
  'addField.url' => {
    'lastUpdated' => '1178799591',
    'message' => 'URL, die Content Manager besuchen, wenn Sie ein neues Feld zum Formular hinzufügen wollen.'
  },
  'addTab.label' => {
    'lastUpdated' => '1178799615',
    'message' => 'Das Standard Label für die addTab.url Variable.'
  },
  'addTab.url' => {
    'lastUpdated' => '1178799653',
    'message' => 'URL, die Content Manager besuchen, wenn Sie einen neuen Tab zum Formular hinzufügen wollen.'
  },
  'assetName' => {
    'lastUpdated' => '1170409301',
    'message' => 'Daten-Formular'
  },
  'back.label' => {
    'lastUpdated' => '1178800087',
    'message' => 'Das Standard Label für die back.url Variable.'
  },
  'back.url' => {
    'lastUpdated' => '1178800120',
    'message' => 'URL, die Sie zurück zur Standard Seite des Formulars bringt.'
  },
  'canEdit' => {
    'lastUpdated' => '1178800165',
    'message' => 'Kode, damit Tabs richtig funktionieren.'
  },
  'canViewEntries' => {
    'lastUpdated' => '1192818609',
    'message' => 'Diese Template-Variable ist wahr, wenn dem Benutzer erlaubt wird, die Liste der vorgelegten DataForm Einträgen anzusehen.'
  },
  'confirm delete all' => {
    'lastUpdated' => '1178800209',
    'message' => 'Sind Sie sich sicher,dass Sie all Daten Formular Einträge löschen wollen?'
  },
  'confirm delete one' => {
    'lastUpdated' => '1178800242',
    'message' => 'Sind Sie sich sicher, dass Sie diesen Eintrag löschen wollen?'
  },
  'data form' => {
    'lastUpdated' => '1178800252',
    'message' => 'Daten Formular'
  },
  'data form asset template variables body' => {
    'lastUpdated' => '1178796036',
    'message' => 'Jedes Asset bietet ihren Templates einen Satz an Variablen, die auf den Asset Eigenschaften basieren. Einige dieser Variablen können nützlich sein, andere nicht.'
  },
  'data form asset template variables title' => {
    'lastUpdated' => '1178796024',
    'message' => 'Daten Formular Asset Template Variablen'
  },
  'data list' => {
    'lastUpdated' => '1178800260',
    'message' => 'Daten Liste'
  },
  'date' => {
    'lastUpdated' => '1178800364',
    'message' => 'Das Datum, zu dem das Formular abgeschickt oder zum letzten Mal akutlisiert wurde. Hat das für den Benutzer eingestellte Datums-/Zeitformat.'
  },
  'defaultView' => {
    'lastUpdated' => '1178800373',
    'message' => 'Standard Ansicht'
  },
  'defaultView description' => {
    'lastUpdated' => '1178800464',
    'message' => 'Wählen Sie die Standard Ansicht für dieses Daten Formular, entweder Formularansicht (Standard) oder Listenansicht. Falls die Listenansicht eingestellt ist, wird keine Best&auml;tigung angezeigt, nachdem Daten in das Formular eingegeben wurden.'
  },
  'defaultView var desc' => {
    'lastUpdated' => '1178800531',
    'message' => 'Wahr, falls für das Daten Formular die Listenansicht (nicht die Formularansicht) als Standard eingestellt ist.'
  },
  'delete file' => {
    'lastUpdated' => '1178800557',
    'message' => 'Angehängte Datei löschen'
  },
  'delete.label' => {
    'lastUpdated' => '1178800580',
    'message' => 'Das Standard Label für die delete.url Variable.'
  },
  'delete.url' => {
    'lastUpdated' => '1178800610',
    'message' => 'URL zum Löschen des aktuellen Eintrags im Daten Formular.'
  },
  'deleteAllEntries.label' => {
    'lastUpdated' => '1178800635',
    'message' => 'Das Standard Label für die deleteAllEntries.url Variable.'
  },
  'deleteAllEntries.url' => {
    'lastUpdated' => '1178800666',
    'message' => 'URL zum Löschen aller Einträge des Daten Formulars.'
  },
  'edit.url' => {
    'lastUpdated' => '1178800688',
    'message' => 'URL zur Seite, um diesen Eintrag zu bearbeiten.'
  },
  'editField extras label' => {
    'lastUpdated' => '1178800695',
    'message' => 'Extras'
  },
  'editField extras label description' => {
    'lastUpdated' => '1178800750',
    'message' => 'Hier können sie zusätzliche Tag Eigenschaften für das Feld Tag eingeben. Zum Beispiel \'class="meineKlasse".'
  },
  'editField vertical label' => {
    'lastUpdated' => '1178800766',
    'message' => 'Vertikal ausrichten (alignment)'
  },
  'editField vertical label description' => {
    'lastUpdated' => '1178800810',
    'message' => 'Diese Eigenschaft legt fest, ob Radio Buttons und Checklisten horizontal oder vertikal ausgerichtet werden.'
  },
  'editField vertical subtext' => {
    'lastUpdated' => '1178800847',
    'message' => 'Diese Eigenschaft beeinflusst nur Radiolisten und Checklisten.'
  },
  'editForm useCaptcha description' => {
    'lastUpdated' => '1217254400',
    'message' => '<p>Falls \'ja\', so benötigen Datenformulare CAPTCHAS für Besucher (Visitors). Registrierte Benutzer (Registered Users) sehen das CAPTCHA nicht.</p>'
  },
  'editForm useCaptcha label' => {
    'lastUpdated' => '1217254418',
    'message' => 'Captchas für Besucher (Visitors) benutzen?'
  },
  'editForm workflowIdAddEntry description' => {
    'lastUpdated' => '1226012853',
    'message' => 'Workflow der ausgeführt wird, wenn ein neuer Eintrag in enem &quot;Daten Formular&quot; erfolgt.'
  },
  'editForm workflowIdAddEntry label' => {
    'lastUpdated' => '1226012979',
    'message' => 'Workflow für neuen Eintrag'
  },
  'emailTemplateId' => {
    'lastUpdated' => '1178800906',
    'message' => 'Die ID des Templates für das Senden der in das Daten Formular eingegebenen Benutzerdaten per Email.'
  },
  'entryId' => {
    'lastUpdated' => '1178800992',
    'message' => 'Die ID des aktuell betrachteten Eintrags. Diese Variable ist undefiniert, ausser der Benutzer kann das Daten Formular editieren (<strong>canEdit</strong> ist wahr).'
  },
  'entryList.label' => {
    'lastUpdated' => '1178801016',
    'message' => 'Das Standard Label für die entryList.url Variable.'
  },
  'entryList.url' => {
    'lastUpdated' => '1178801051',
    'message' => 'URL zur Anzeige aller Daten Einträge dieses Daten Formulars.'
  },
  'epoch' => {
    'lastUpdated' => '1178801108',
    'message' => 'Das Datum, an dem die Daten eingegeben oder als letztes aktualisiert wurden als epoch Datum.'
  },
  'error captcha' => {
    'lastUpdated' => '1217254443',
    'message' => 'CAPTCHA wurde falsch eingegeben. Bitte versuchen Sie es noch einmal.'
  },
  'error.message' => {
    'lastUpdated' => '1178801180',
    'message' => 'Eine Fehlermeldung, die angibt, was der Benutzer falsch gemacht haben könnte.'
  },
  'error_loop' => {
    'lastUpdated' => '1178801236',
    'message' => 'Eine Schleife, die Fehlerinfos enthält. Zum Beispiel wenn jemand ein erforderliches Feld nicht ausgefüllt hat.'
  },
  'export.tab.label' => {
    'lastUpdated' => '1178801261',
    'message' => 'Das Standard Label für die export.tab.url Variable.'
  },
  'export.tab.url' => {
    'lastUpdated' => '1178801329',
    'message' => 'URL zum Exportieren der Daten in eine Datei, in der die Daten mittels Tabs voneinander getrennt sind (vgl. csv Dateien).'
  },
  'field.controls' => {
    'lastUpdated' => '1178801365',
    'message' => 'WebGUIs administrative Kontrollelemente für das Bearbeiten dieses Feldes.'
  },
  'field.form' => {
    'lastUpdated' => '1178801381',
    'message' => 'Das Formular Element dieses Feldes.'
  },
  'field.id' => {
    'lastUpdated' => '1178801409',
    'message' => 'Ein eindeutiger Bezeichner, das das Feld in der Datenbank identifiziert.'
  },
  'field.inTab' => {
    'lastUpdated' => '1178801442',
    'message' => 'Bedingung, die angibt, ob das Feld innerhalb eines Tabs ist.'
  },
  'field.isDisplayed' => {
    'lastUpdated' => '1178801474',
    'message' => 'Bedingung, die angibt, ob das Feld angezeigt wird.'
  },
  'field.isHidden' => {
    'lastUpdated' => '1178801495',
    'message' => 'Bedingung, die angibt, ob das Feld ein verstecktes Feld ist.'
  },
  'field.isMailField' => {
    'lastUpdated' => '1178801529',
    'message' => 'Bedingung, die angibt, ob das Feld nur anwesend ist, um Email zu verschicken.'
  },
  'field.isRequired' => {
    'lastUpdated' => '1178801551',
    'message' => 'Bedingung, die angibt, ob das Feld erforderlich ist.'
  },
  'field.label' => {
    'lastUpdated' => '1178801982',
    'message' => 'Das Text Label für dieses Feld.'
  },
  'field.name' => {
    'lastUpdated' => '1178801998',
    'message' => 'Der Name dieses Feldes.'
  },
  'field.subtext' => {
    'lastUpdated' => '1178802044',
    'message' => 'Eine Beschreibung des Feldes, damit der Benutzer weiss, was er in das Feld eingeben muss.'
  },
  'field.tid' => {
    'lastUpdated' => '1178802065',
    'message' => 'Die ID des Tabs, in dem das Feld sich befindet.'
  },
  'field.type' => {
    'lastUpdated' => '1178802085',
    'message' => 'Der Datentyp, der mit dem Feld assoziiert ist.'
  },
  'field.value' => {
    'lastUpdated' => '1178802182',
    'message' => 'Der Wert dieses Feldes. Falls dies neue Daten sind, so wird der Standard Wert benutzt.'
  },
  'field_loop' => {
    'lastUpdated' => '1178802570',
    'message' => '<p>Eine Schleife, die alle Informationen des Feldes enthält. Auch von außerhalb der <strong>field_loop</strong> ist es ein direkter Zugriff auf alle Formular Felder möglich. Um dies zu erreichen, sollten Sie diese Variablen nutzen. Rufen sie diese über <strong>field.noloop.<em>fieldName</em>.<em>property</em></strong> auf, wobei fieldName der Name des Feldes (nicht des Labels) und property eine der Eigenschaften, die von <strong>field_loop</strong> bereitgestellt wird, ist. Wenn Sie das &#39;form&#39; Tag des Feldes &#39;name&#39; ben&ouml;tigen, schreiben Sie <strong>field.noloop.name.form</strong> irgendwo in ihrem Template. Wenn Sie wissen wollen, ob das Feld erforderlich ist, schreiben Sie <strong>field.noloop.name.isRequired</strong>.</p>'
  },
  'form.end' => {
    'lastUpdated' => '1178802592',
    'message' => 'Das Ende des Formulars.'
  },
  'form.save' => {
    'lastUpdated' => '1178802616',
    'message' => 'Eine Formular Schaltfläche, um die Daten abzuschicken.'
  },
  'form.send' => {
    'lastUpdated' => '1178802659',
    'message' => 'Eine Formularschaltfläche, mit der internationalisierten Aufschrift "send".'
  },
  'form.start' => {
    'lastUpdated' => '1178802675',
    'message' => 'Der Anfang des Formulars.'
  },
  'go to form' => {
    'lastUpdated' => '1178802694',
    'message' => 'Gehe zum Formular'
  },
  'group to view entries' => {
    'lastUpdated' => '1178802792',
    'message' => 'Gruppe, die Daten Formular Einträge ansehen darf'
  },
  'group to view entries description' => {
    'lastUpdated' => '1178802761',
    'message' => 'Mitglieder dieser Gruppe können die Daten ansehen, die mittels diesem Daten Formular Asset eingegeben wurden.'
  },
  'groupToViewEntries' => {
    'lastUpdated' => '1178802864',
    'message' => 'Die Gruppen ID der Gruppe, die die eingegebenen Daten des Formulars einsehen dürfen, wenn das Formular sich im Formular Modus befindet.'
  },
  'hasEntries' => {
    'lastUpdated' => '1178802889',
    'message' => 'Die Anzahl der Daten Einträge dieses Daten Formulars.'
  },
  'help record.noloop' => {
    'lastUpdated' => '1253863904',
    'message' => 'Durch den Namen erhalten Sie jeden Feldwert, Bsp.: record.noloop.subject'
  },
  'helpvar form.captcha' => {
    'lastUpdated' => '1217254467',
    'message' => 'Das Eingabefeld und Bild für das CAPTCHA'
  },
  'helpvar useCaptcha' => {
    'lastUpdated' => '1217254493',
    'message' => 'Diese Variable ist wahr, falls das CAPTCHA angezeigt werden soll.'
  },
  'htmlAreaRichEditor' => {
    'lastUpdated' => '1242498025',
    'message' => 'HTML-Area Rich Editor'
  },
  'htmlAreaRichEditor description' => {
    'lastUpdated' => '1242498102',
    'message' => 'Selektieren Sie den Rich Editor für die Bearbeitung von HTML-Text-Feldern.
Der Standard-Editor wurde in den Voreinstellungen dieses Servers festgelegt.'
  },
  'ipAddress' => {
    'lastUpdated' => '1178802912',
    'message' => 'Die IP Adresse des Benutzers, der diese Daten eingegeben hat.'
  },
  'javascript.confirmation.deleteAll' => {
    'lastUpdated' => '1178802990',
    'message' => 'Javascript für ein internationalisiertes Pop Up Fenster, in dem man zur Bestätigung des Löschens aller Dateneintr&auml;ge aufgefordert wird.'
  },
  'javascript.confirmation.deleteOne' => {
    'lastUpdated' => '1178803035',
    'message' => 'Javascript für ein internationalisiertes Pop Up Fenster, in dem man zur Bestätigung des Löschens eines Dateneintrags aufgefordert wird.'
  },
  'listTemplateId' => {
    'lastUpdated' => '1178803075',
    'message' => 'Die ID des Templates, das zur Anzeige der Listenansicht des Daten Formulars benutzt wird.'
  },
  'mail attachments' => {
    'lastUpdated' => '1178803090',
    'message' => 'Email Anhänge?'
  },
  'mail attachments description' => {
    'lastUpdated' => '1178803243',
    'message' => 'Muss in Verbindung mit \'mailData\' benutzt werden. Wenn Sie dies auf Ja setzen, werden alle Dateien, die via eines Datei Feld Typen abgeschickt wurden, als Email Anhang verschickt.'
  },
  'mailAttachments' => {
    'lastUpdated' => '1178803321',
    'message' => 'mailAttachments wird wahr, falls das Daten Formular so konfiguriert wurde, dass Dateien per Email verschickt werden.'
  },
  'mailData' => {
    'lastUpdated' => '1178803228',
    'message' => 'mailData wird wahr, falls ein Daten Formular so konfiguriert wurde, dass es Emails verschickt.'
  },
  'no tab' => {
    'lastUpdated' => '1178803331',
    'message' => 'Kein Tab'
  },
  'record.data.isMailField' => {
    'lastUpdated' => '1178803385',
    'message' => 'Bedingung, die angibt, ob dieses Feld wegen Email Funktionalität des Daten Formulars existiert.'
  },
  'record.data.label' => {
    'lastUpdated' => '1178803413',
    'message' => 'Das menschenlesbare Label für dieses Feld.'
  },
  'record.data.name' => {
    'lastUpdated' => '1178803433',
    'message' => 'Der Name dieses Feldes (web safe).'
  },
  'record.data.value' => {
    'lastUpdated' => '1178803476',
    'message' => 'Der Wert, der für dieses Feld in diesem Datensatz vom Benutzer eingegeben wurde.'
  },
  'record.data_loop' => {
    'lastUpdated' => '1178803534',
    'message' => 'Eine Schleife, die die eingegebenen Daten eines Benutzers für jedes Feld in diesem Daten Formular enthält.'
  },
  'record.delete.icon' => {
    'lastUpdated' => '1178803567',
    'message' => 'Ein Icon und die zugehörige URL, um diesen Datensatz zu l&ouml;schen.'
  },
  'record.delete.url' => {
    'lastUpdated' => '1178803592',
    'message' => 'URL, um diesen Datensatz zu löschen.'
  },
  'record.edit.icon' => {
    'lastUpdated' => '1178803618',
    'message' => 'Ein Icon und die zugehörige URL, um diesen Datensatz zu bearbeiten.'
  },
  'record.edit.url' => {
    'lastUpdated' => '1178803637',
    'message' => 'URL, um diesen Datensatz zu bearbeiten.'
  },
  'record.entryId' => {
    'lastUpdated' => '1178803662',
    'message' => 'Ein eindeutiger Bezeichner für diese Datensatz.'
  },
  'record.ipAddress' => {
    'lastUpdated' => '1178803685',
    'message' => 'Die IP Adresse des Benutzers, der diesen Datensatz eingegeben hat.'
  },
  'record.submissionDate.epoch' => {
    'lastUpdated' => '1178803710',
    'message' => 'Der epoch Datumseintrag für diesen Datensatz.'
  },
  'record.submissionDate.human' => {
    'lastUpdated' => '1178803764',
    'message' => 'Datumseintrag für diesen Datensatz. Format wie im Benutzerprofil angegeben.'
  },
  'record.userId' => {
    'lastUpdated' => '1178803789',
    'message' => 'Die Benutzer ID der Person, die diesen Datensatz eingegeben hat.'
  },
  'record.username' => {
    'lastUpdated' => '1178803806',
    'message' => 'Der Benutzername der Person, die diesen Datensatz eingegeben hat.'
  },
  'record_data_type' => {
    'lastUpdated' => '1192818657',
    'message' => '<p>Der Datentyp ist mit diesem Feld verbunden.</p>'
  },
  'record_loop' => {
    'lastUpdated' => '1178803840',
    'message' => 'Eine Schleife, dei alle Datensätze dieses Daten Formulars enth&auml;lt.'
  },
  'store data' => {
    'lastUpdated' => '1217254508',
    'message' => 'Daten speichern'
  },
  'store data description' => {
    'lastUpdated' => '1217254527',
    'message' => 'Sollen übergebene Daten gespeichert werden'
  },
  'tab.controls' => {
    'lastUpdated' => '1178803862',
    'message' => 'Bearbeitungsicons für diesen Tab.'
  },
  'tab.end' => {
    'lastUpdated' => '1178803875',
    'message' => 'Kode, um Tab zu beenden.'
  },
  'tab.field.controls' => {
    'lastUpdated' => '1178803906',
    'message' => 'WebGUIs administrative Kontrollelemente für das Bearbeiten dieses Feldes.'
  },
  'tab.field.form' => {
    'lastUpdated' => '1178803932',
    'message' => 'Das Formular Element für dieses Feld.'
  },
  'tab.field.isDisplayed' => {
    'lastUpdated' => '1178803951',
    'message' => 'Bedingung, die angibt, ob dieses Feld angezeigt wird.'
  },
  'tab.field.isHidden' => {
    'lastUpdated' => '1178803967',
    'message' => 'Bedingung, die angibt, ob dieses Feld versteckt ist.'
  },
  'tab.field.isMailField' => {
    'lastUpdated' => '1178804005',
    'message' => 'Bedingung, die angibt, ob dieses Feld vorhanden ist, um Emailing möglich zu machen.'
  },
  'tab.field.isRequired' => {
    'lastUpdated' => '1178804032',
    'message' => 'Bedingung, die angibt, ob dieses Feld erforderlich ist.'
  },
  'tab.field.label' => {
    'lastUpdated' => '1178804047',
    'message' => 'Das Text Label für dieses Feld.'
  },
  'tab.field.name' => {
    'lastUpdated' => '1178804056',
    'message' => 'Der Name dieses Feldes.'
  },
  'tab.field.subtext' => {
    'lastUpdated' => '1178804079',
    'message' => 'Eine Beschreibung dieses Feldes, damit der Benutzer weiss, was er eintragen muss.'
  },
  'tab.field.tid' => {
    'lastUpdated' => '1178804101',
    'message' => 'Die ID des Tabs, in dem das Feld sich befindet.'
  },
  'tab.field.value' => {
    'lastUpdated' => '1178804138',
    'message' => 'Der Wert dieses Feldes. Falls dies neue Daten sind, so wird der Standard Wert benutzt.'
  },
  'tab.field_loop' => {
    'lastUpdated' => '1178804247',
    'message' => 'Eine Schleife, die alle Felder für diesen Tab enthält. Siehe auch <strong>field_loop</strong>, um zu sehen, welche Template Variablen in der Schleife genutzt werden können.'
  },
  'tab.init' => {
    'lastUpdated' => '1178804302',
    'message' => 'Kode, damit Tabs richtig funktionieren.'
  },
  'tab.label' => {
    'lastUpdated' => '1178804317',
    'message' => 'Das Label für diesen Tab.'
  },
  'tab.sequence' => {
    'lastUpdated' => '1178804349',
    'message' => 'Eine Nummer, die angibt welcher Tab dies ist (der erste, zweite, etc.).'
  },
  'tab.start' => {
    'lastUpdated' => '1178804361',
    'message' => 'Kode, um den Tab zu starten.'
  },
  'tab.subtext' => {
    'lastUpdated' => '1178804438',
    'message' => 'Eine Beschreibung dieses Tabs, die mehr über den Inhalt des Tabs aufklären kann als das Label.'
  },
  'tab.tid' => {
    'lastUpdated' => '1178804453',
    'message' => 'Die ID dieses Tabs.'
  },
  'tab_loop' => {
    'lastUpdated' => '1178804501',
    'message' => 'Eine Schleife, die Informationen über die Tabs enthält, die f&uuml;r dieses Daten Formular definiert wurden.'
  },
  'template captcha label' => {
    'lastUpdated' => '1253185029',
    'message' => 'Geben Sie die nachfolgende Zeichenfolge ein'
  },
  'templateId' => {
    'lastUpdated' => '1178804553',
    'message' => 'Die ID des Templates, das für die Anzeige der Formularansicht des Daten Formulars benutzt wird.'
  },
  'userId' => {
    'lastUpdated' => '1178804577',
    'message' => 'Die Benuter ID des Benutzers, der die Daten eingegeben hat.'
  },
  'username' => {
    'lastUpdated' => '1178804598',
    'message' => 'Der Benutzername des Benutzers, der die Daten eingegeben hat.'
  }
}
;

1;
